/* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
/** @brief library to drive a WS2812b LED chain (API)
 *  @file led_ws2812b.h
 *  @author King Kévin <kingkevin@cuvoodoo.info>
 *  @date 2016
 *  @note peripherals used: SPI @ref led_ws2812b_spi, timer @ref led_ws2812b_timer, DMA @ref led_ws2812b_dma
 */
#pragma once

/** number of LEDs on the WS2812b strip */
#define WS2812B_LEDS 48

/** @brief setup WS2812b LED driver */
void ws2812b_setup(void);
/** @brief set color of a single LED
 *  @param[in] led the LED number to set the color
 *  @param[in] red the red color value to set on the LED
 *  @param[in] green the green color value to set on the LED
 *  @param[in] blue the blue color value to set on the LED
 *  @note transmission needs to be done separately
 */
void ws2812b_set_rgb(uint16_t led, uint8_t red, uint8_t green, uint8_t blue);
/** @brief transmit color values to WS2812b LEDs */
void ws2812b_transmit(void);
